# 990_copy_bprestorelog.sh
# copy the logfiles to the recovered system, at least the part that has been written till now.

# $VAR_DIR/restore will be copied to $recovery_system_recover_log_dir in wrapup/default/990_copy_logfile.sh
mkdir -p "$VAR_DIR/restore/netbackup"
cp -pr /usr/openv/netbackup/logs/* "$VAR_DIR/restore/netbackup"

# take care of $VAR_DIR/restore/bplog.restore* files (that used to be in /root before)
function symlink_bprestore_logs ()
{
    # adapted from wrapup/default/990_copy_logfile.sh
    local final_logfile_name_full
    local final_logfile_name
    local log_file_symlink_target
    local log_file_symlink
    local recover_log_dir=$LOG_DIR/recover
    local recovery_system_recover_log_dir=$TARGET_FS_ROOT/$recover_log_dir
    # Create the directories with mode 0700 (rwx------) so that only root can access files and subdirectories therein
    # because in particular logfiles could contain security relevant information.

    # To be backward compatible with where to the logfile was copied before
    # have it as a symbolic link that points to where the logfile actually is:
    # ( "roots" in recovery_system_roots_home_dir means root's but ' in a variable name is not so good ;-)
    local recovery_system_roots_home_dir=$TARGET_FS_ROOT/$ROOT_HOME_DIR
    test -d $recovery_system_roots_home_dir || mkdir $verbose -m 0700 $recovery_system_roots_home_dir

    # Remove existing and now outdated symlinks that would falsely point to the same target
    # The symlink name bplog.restore-$( date -Iseconds ).log is for example bplog.restore-2019-12-17T09:40:36+01:00.log or rear-2006-08-14T02:34:56-06:00.log
    # so a matching globbing pattern is bplog.restore-[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]T[0-9][0-9]:[0-9][0-9]:[0-9][0-9]*.log ('*' for the UTC offset):
    for log_file_symlink in $recovery_system_roots_home_dir/bplog.restore*-[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]T[0-9][0-9]:[0-9][0-9]:[0-9][0-9]*.log ; do
        # Skip if a file that matches the globbing pattern is not a symlink (it could be even a directory full of user's sacrocanct files):
        test -L $log_file_symlink || continue
        # Remove also outdated dangling symlinks where their target does not exist by using 'readlink -m':
        test "$log_file_symlink_target" = "$( readlink -m $log_file_symlink )" || continue
        rm $verbose $log_file_symlink
    done

    # At the moment this function runs, $VAR_DIR/restore will have been already copied
    # to $recovery_system_recover_log_dir in wrapup/default/990_copy_logfile.sh
    # (exit tasks run in reverse order, so this task will run after the tasks defined in
    # wrapup/default/990_copy_logfile.sh )
    for final_logfile_name_full in $recovery_system_recover_log_dir/restore/bplog.restore* ; do
        final_logfile_name="$( basename "$final_logfile_name_full" )"
        log_file_symlink_target="$recover_log_dir/restore/$final_logfile_name"
        # Create symlink with current timestamp that points to where the logfile actually is:
        log_file_symlink=$recovery_system_roots_home_dir/$( basename "$final_logfile_name" .log )-$( date -Iseconds ).log
        ln $verbose -s $log_file_symlink_target $log_file_symlink || true
    done
}

AddExitTask "symlink_bprestore_logs"
